#ifndef SOCKET_SET_H
#define SOCKET_SET_H

/*!
  \file
  \brief ʐM\PbgǗ

  \author Satofumi KAMIMURA

  $Id$
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#if !HAVE_CONFIG_H || HAVE_LIBSDL_NET
#include <SDL_net.h>
#else
class TCPsocket;
#endif
#include <memory>

class TcpipCtrl;


/*!
  \brief ʐM\PbgǗ
*/
class SocketSet {
  SocketSet(const SocketSet& rhs);
  SocketSet& operator = (const SocketSet& rhs);

  struct pImpl;
  const std::auto_ptr<pImpl> pimpl;

public:
  /*!
    \brief RXgN^

    \param size [i] Ԃł̃\Pbge
  */
  explicit SocketSet(size_t size = 1);
  ~SocketSet(void);

  /*!
    \brief \Pbg̓o^

    \param socket [i] o^\Pbg

    \retval true o^ɐ
    \retval false o^Ɏs
  */
  bool add(TCPsocket socket);

  /*!
    \brief \Pbg̍폜

    \param socket [i] 폜\Pbg
  */
  void del(TCPsocket socket);

  /*!
    \brief Mf[^邩̊mF

    \param timeout [i] ^CAEg [msec]

    \return Mf[^̂\Pbg
  */
  size_t check(int timeout);
};

#endif /* !SOCKET_SET_H */
